function varargout = ayudaprocesado(varargin)
% AYUDAPROCESADO M-file for ayudaprocesado.fig
%      AYUDAPROCESADO, by itself, creates a new AYUDAPROCESADO or raises the existing
%      singleton*.
%
%      H = AYUDAPROCESADO returns the handle to a new AYUDAPROCESADO or the handle to
%      the existing singleton*.
%
%      AYUDAPROCESADO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in AYUDAPROCESADO.M with the given input arguments.
%
%      AYUDAPROCESADO('Property','Value',...) creates a new AYUDAPROCESADO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ayudaprocesado_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ayudaprocesado_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
% Copyright 2002-2003 The MathWorks, Inc.
% Edit the above text to modify the response to help ayudaprocesado
% Last Modified by GUIDE v2.5 25-Mar-2002 12:19:15

%DEFINICIÓN FUNCIÓN
%Cuadro de ayuda que aparece al pulsar el botón de Ayuda en la ventana de
%Procesado.

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ayudaprocesado_OpeningFcn, ...
                   'gui_OutputFcn',  @ayudaprocesado_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before ayudaprocesado is made visible.
function ayudaprocesado_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ayudaprocesado (see VARARGIN)

% Choose default command line output for ayudaprocesado
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes ayudaprocesado wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = ayudaprocesado_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
